==> cpppo-2.8.0.tar.gz: cpppo-2.8.0/history/__init__.py <==

# 
# Cpppo -- Communication Protocol Python Parser and Originator
# 
# Copyright (c) 2013, Hard Consulting Corporation.
# 
# Cpppo is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.  See the LICENSE file at the top of the source tree.
# 
# Cpppo is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
# 

from __future__ import absolute_import
from __future__ import print_function
from __future__ import division

__author__                      = "Perry Kundert"
__email__                       = "perry@hardconsulting.com"
__copyright__                   = "Copyright (c) 2013 Hard Consulting Corporation"
__license__                     = "Dual License: GPLv3 (or later) and Commercial (see LICENSE)"

__all__				= ["timestamp", "get_localzone", "zone_names",
                                   "parse_offset", "format_offset", "AmbiguousTimeZoneError",
                                   "opener", "logger", "parse_record",
                                   "HistoryExhausted", "reader", 
                                   "DataError", "IframeError", "loader"]

# These modules form the public interface of cpppo.history
from .files import *
from .times import *

==> cpppo-3.5.3.tar.gz: cpppo-3.5.3/history/__init__.py <==

# 
# Cpppo -- Communication Protocol Python Parser and Originator
# 
# Copyright (c) 2013, Hard Consulting Corporation.
# 
# Cpppo is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.  See the LICENSE file at the top of the source tree.
# 
# Cpppo is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
# 

from __future__ import absolute_import
from __future__ import print_function
from __future__ import division

__author__                      = "Perry Kundert"
__email__                       = "perry@hardconsulting.com"
__copyright__                   = "Copyright (c) 2013 Hard Consulting Corporation"
__license__                     = "Dual License: GPLv3 (or later) and Commercial (see LICENSE)"

__all__				= ["timestamp", "get_localzone", "zone_names", "timedelta_total_seconds",
                                   "parse_offset", "format_offset", "AmbiguousTimeZoneError",
                                   "opener", "logger", "parse_record",
                                   "HistoryExhausted", "reader", 
                                   "DataError", "IframeError", "loader"]

# These modules form the public interface of cpppo.history
from .files import *
from .times import *
